@@ -8,7 +8,7 @@
 #'
 #' @export
 #' @param model An object of class \code{hmm} or \code{mhmm}.
-#' @param em_step Logical. Whether or not to use the EM algorithm at the start 
+#' @param em_step Logical. Whether or not to use the EM algorithm at the start
 #'   of the parameter estimation. The default is \code{TRUE}.
 #' @param global_step Logical. Whether or not to use global optimization via
 #'   \code{\link{nloptr}} (possibly after the EM step). The default is \code{FALSE}.
@@ -23,17 +23,17 @@
 #'   and for mixture models 3 (print also during optimization of coefficients).}
 #'   \item{reltol}{Relative tolerance for convergence defined as
 #'   \eqn{(logLik_new - logLik_old)/(abs(logLik_old) + 0.1)}.
-#'   The default is 1e-12.}
-#'   \item{restart}{A list containing options for possible EM restarts with the 
+#'   The default is 1e-10.}
+#'   \item{restart}{A list containing options for possible EM restarts with the
 #'     following components:
 #'   \describe{
 #'   \item{times}{Number of restarts of the EM algorithm using random initial values. The default is 0, i.e. no restarts. }
 #'   \item{transition}{Logical. Should the original transition probabilities be varied? The default is \code{TRUE}. }
 #'   \item{emission}{Logical. Should the original emission probabilities be varied? The default is \code{TRUE}. }
 #'   \item{sd}{Standard deviation for \code{rnorm} used in randomization. The default is 0.25.}
-#'   \item{maxeval}{Maximum number of iterations, the default is 100.}
+#'   \item{maxeval}{Maximum number of iterations, the default is \code{control_em$maxeval}}
 #'   \item{print_level}{Level of printing in restarted EM steps. The default is \code{control_em$print_level}. }
-#'   \item{reltol}{Relative tolerance for convergence at restarted EM steps. The default is 1e-8.
+#'   \item{reltol}{Relative tolerance for convergence at restarted EM steps. The default is \code{control_em$reltol}.
 #'   If the relative change of the final model of the restart phase is larger than the tolerance
 #'   for the original EM phase, the final model is re-estimated with the original \code{reltol}
 #'   and \code{maxeval} at the end of the EM step.}
@@ -52,7 +52,7 @@
 #'    \item{maxtime}{\code{60} (maximum time for global optimization. Set to 0 for unlimited time.)}
 #'}
 #' @param lb,ub Lower and upper bounds for parameters in Softmax parameterization.
-#' The default interval is \eqn{[pmin(-25, 2*initialvalues), pmax(25, 2*initialvalues)]}, 
+#' The default interval is \eqn{[pmin(-25, 2*initialvalues), pmax(25, 2*initialvalues)]},
 #' except for beta coefficients,
 #' where the scale of covariates is taken into account.
 #' Note that it might still be a good idea to scale covariates around unit scale.
@@ -95,8 +95,8 @@
 #'
 #'   It is possible to rerun the EM algorithm automatically using random starting
 #'   values based on the first run of EM. Number of restarts is defined by
-#'   the \code{restart} argument in \code{control_em}. As the EM algorithm is 
-#'   relatively fast, this method might be preferred option compared to the proper 
+#'   the \code{restart} argument in \code{control_em}. As the EM algorithm is
+#'   relatively fast, this method might be preferred option compared to the proper
 #'   global optimization strategy of step 2.
 #'
 #'   The default global optimization method (triggered via \code{global_step = TRUE}) is
@@ -164,7 +164,7 @@
 #'
 #' \dontrun{
 #' set.seed(21)
-#' fit_hmm_mvad <- fit_model(init_hmm_mvad, control_em = list(restart = list(times = 100)))
+#' fit_hmm_mvad <- fit_model(init_hmm_mvad, control_em = list(restart = list(times = 50)))
 #' hmm_mvad <- fit_hmm_mvad$model
 #' }
 #'
@@ -172,7 +172,7 @@
 #' data("hmm_mvad")
 #'
 #' # Markov model
-#' 
+#'
 #' set.seed(123)
 #' init_mm_mvad <- build_mm(observations = mvad_seq,
 #'   transition_probs = simulate_transition_probs(6),
@@ -275,12 +275,13 @@
 #' # (here threads = 1 for portability issues)
 #' set.seed(123)
 #' hmm_5 <- fit_model(
-#'    init_hmm_bf, em_step = FALSE, global_step = TRUE, local_step = TRUE, lb = -50, ub = 50,
-#' control_global = list(algorithm = "NLOPT_GD_STOGO", maxeval = 2500, maxtime = 0), threads = 1)
+#'    init_hmm_bf, em_step = FALSE, global_step = TRUE, local_step = TRUE, 
+#'    lb = -50, ub = 50, control_global = list(algorithm = "NLOPT_GD_STOGO", 
+#'    maxeval = 2500, maxtime = 0), threads = 1)
 #' hmm_5$logLik # -21675.4
-#' 
+#'
 #' ##############################################################
-#' 
+#'
 #' # Mixture HMM
 #'
 #' data("biofam3c")
@@ -471,7 +472,7 @@ fit_model <- function(model, em_step = TRUE, global_step = FALSE, local_step = F
     emissionArray[,1:model$n_symbols[i],i]<-model$emission_probs[[i]]
 
   if (em_step) {
-    em.con <- list(print_level = 0, maxeval = 1000, reltol = 1e-12, restart = NULL)
+    em.con <- list(print_level = 0, maxeval = 1000, reltol = 1e-10, restart = NULL)
     nmsC <- names(em.con)
     em.con[(namc <- names(control_em))] <- control_em
     if (length(noNms <- namc[!namc %in% nmsC]))
@@ -516,8 +517,9 @@ fit_model <- function(model, em_step = TRUE, global_step = FALSE, local_step = F
 
 
     if (!is.null(em.con$restart)) {
-      restart.con <- list(times = 0, print_level = em.con$print_level, maxeval = 100, reltol = 1e-8,
-        transition = TRUE, emission = TRUE, sd = 0.25,
+      restart.con <- list(times = 0, print_level = em.con$print_level,
+        maxeval = em.con$maxeval, reltol = em.con$reltol,
+        transition = TRUE, emission = TRUE, coef = FALSE, sd = 0.25,
         n_optimum = min(control_em$restart$times + 1, 25))
       nmsC <- names(restart.con)
       restart.con[(namc <- names(control_em$restart))] <- control_em$restart
@@ -543,9 +545,11 @@ fit_model <- function(model, em_step = TRUE, global_step = FALSE, local_step = F
         random_trans <- resEM$transitionMatrix
         random_trans[(random_trans < 1e-4) & (model$transition_probs > 0)] <- 1e-4
         random_trans <- random_trans / rowSums(random_trans)
+        random_coef <- resEM$coefficients
       } else {
         random_emiss <- emissionArray
         random_trans <- model$transition_probs
+        random_coef <- model$coefficients
       }
 
       if (restart.con$transition) {
@@ -559,6 +563,12 @@ fit_model <- function(model, em_step = TRUE, global_step = FALSE, local_step = F
         base_emiss <- random_emiss[nz_emiss]
       }
 
+      if (restart.con$coef) {
+        base_coef <- random_coef
+        coef_scale <- max(abs(base_coef))
+        n_coef <- length(base_coef)
+      }
+
       for (i in 1:restart.con$times) {
         if (restart.con$transition) {
           random_trans[nz_trans] <- abs(base_trans + rnorm(np_trans, sd = restart.con$sd))
@@ -573,10 +583,13 @@ fit_model <- function(model, em_step = TRUE, global_step = FALSE, local_step = F
               random_emiss[,1:model$n_symbols[j],j] / rowSums(random_emiss[,1:model$n_symbols[j],j])
           }
         }
+        if (restart.con$coef) {
+          random_coef[] <- rnorm(n_coef, base_coef, sd = coef_scale)
+        }
         if (!log_space) {
           if (mhmm) {
             resEMi <- EMx(random_trans, random_emiss, model$initial_probs, obsArray,
-              model$n_symbols, model$coefficients, model$X, model$n_states_in_clusters, restart.con$maxeval,
+              model$n_symbols, random_coef, model$X, model$n_states_in_clusters, restart.con$maxeval,
               restart.con$reltol,restart.con$print_level, threads)
           } else {
             resEMi <- EM(random_trans, random_emiss, model$initial_probs, obsArray,
@@ -585,7 +598,7 @@ fit_model <- function(model, em_step = TRUE, global_step = FALSE, local_step = F
         } else {
           if (mhmm) {
             resEMi <- log_EMx(random_trans, random_emiss, model$initial_probs, obsArray,
-              model$n_symbols, model$coefficients, model$X, model$n_states_in_clusters, restart.con$maxeval,
+              model$n_symbols,random_coef, model$X, model$n_states_in_clusters, restart.con$maxeval,
               restart.con$reltol,restart.con$print_level, threads)
           } else {
             resEMi <- log_EM(random_trans, random_emiss, model$initial_probs, obsArray,
