@@ -2,20 +2,14 @@
 #include "seqHMM.h"
 // [[Rcpp::export]]
 
-NumericVector logLikHMM(const arma::mat& transition, NumericVector emissionArray,
-    const arma::vec& init, IntegerVector obsArray, int threads) {
-
-  IntegerVector eDims = emissionArray.attr("dim"); //m,p,r
-  IntegerVector oDims = obsArray.attr("dim"); //k,n,r
-
-  arma::cube emission(emissionArray.begin(), eDims[0], eDims[1], eDims[2], false, true);
-  arma::icube obs(obsArray.begin(), oDims[0], oDims[1], oDims[2], false, true);
+NumericVector logLikHMM(const arma::mat& transition, const arma::cube& emission,
+    const arma::vec& init, const arma::ucube& obs, unsigned int threads) {
 
   arma::vec ll(obs.n_slices);
   arma::mat transition_t(transition.t());
 #pragma omp parallel for if(obs.n_slices >= threads) schedule(static) num_threads(threads) \
   default(none) shared(ll, obs, init, emission, transition_t)
-  for (int k = 0; k < obs.n_slices; k++) {
+  for (unsigned int k = 0; k < obs.n_slices; k++) {
     arma::vec alpha = init;
     
     for (unsigned int r = 0; r < obs.n_rows; r++) {
