@@ -3,16 +3,9 @@
 #include "seqHMM.h"
 // [[Rcpp::export]]
 
-List log_objective(const arma::mat& transition, NumericVector emissionArray,
-                   const arma::vec& init, IntegerVector obsArray, const arma::imat& ANZ,
-    IntegerVector emissNZ, const arma::ivec& INZ, IntegerVector nSymbols, int threads) {
-
-  IntegerVector eDims = emissionArray.attr("dim"); //m,p,r
-  IntegerVector oDims = obsArray.attr("dim"); //k,n,r
-
-  arma::cube emission(emissionArray.begin(), eDims[0], eDims[1], eDims[2], false, true);
-  arma::icube obs(obsArray.begin(), oDims[0], oDims[1], oDims[2], false, true);
-  arma::icube BNZ(emissNZ.begin(), emission.n_rows, emission.n_cols - 1, emission.n_slices, false, true);
+List log_objective(const arma::mat& transition, const arma::cube& emission,
+                   const arma::vec& init, const arma::ucube& obs, const arma::umat& ANZ,
+    const arma::ucube& BNZ, const arma::uvec& INZ, arma::uvec& nSymbols, unsigned int threads) {
 
   arma::vec grad(arma::accu(ANZ) + arma::accu(BNZ) + arma::accu(INZ), arma::fill::zeros);
 
@@ -27,7 +20,7 @@ List log_objective(const arma::mat& transition, NumericVector emissionArray,
   log_internalBackward(transitionLog, emissionLog, obs, beta, threads);
 
   arma::vec ll(obs.n_slices);
-  for (int k = 0; k < obs.n_slices; k++) {
+  for (unsigned int k = 0; k < obs.n_slices; k++) {
     ll(k) = logSumExp(alpha.slice(k).col(obs.n_cols - 1));
   }
 
@@ -37,7 +30,7 @@ List log_objective(const arma::mat& transition, NumericVector emissionArray,
 #pragma omp parallel for if(obs.n_slices >= threads) schedule(static) num_threads(threads) \
   default(none) shared(alpha, beta, gradmat, nSymbols, ANZ, BNZ, INZ,            \
     obs, init, ll, transition, emission, initLog, transitionLog, emissionLog)
-  for (int k = 0; k < obs.n_slices; k++) {
+  for (unsigned int k = 0; k < obs.n_slices; k++) {
     int countgrad = 0;
 
     // transitionMatrix
